==> seedsui-react-2.6.2.tgz: package/es/Counter/Counter.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { Counter as Instance } from './instance.js';

var Counter = (_temp = _class = function (_Component) {
  _inherits(Counter, _Component);

  function Counter(props) {
    _classCallCheck(this, Counter);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.componentDidMount = function () {
      var instance = new Instance(_this.$el);
      if (_this.props.autoplay) {
        instance.play();
      }
      _this.instance = instance;
    };

    _this.play = function () {
      if (_this.instance) {
        _this.instance.play();
      }
    };

    return _this;
  }

  Counter.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        style = _props.style,
        className = _props.className,
        duration = _props.duration,
        from = _props.from,
        to = _props.to,
        suffix = _props.suffix,
        autoplay = _props.autoplay,
        others = _objectWithoutProperties(_props, ['style', 'className', 'duration', 'from', 'to', 'suffix', 'autoplay']);

    return React.createElement(
      'span',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        }, className: 'counter' + (className ? ' ' + className : ''), style: style, 'data-duration': duration, 'data-from': from, 'data-to': to, 'data-suffix': suffix }, others),
      '1'
    );
  };

  return Counter;
}(Component), _class.defaultProps = {
  duration: 5000,
  from: 0,
  to: 10,
  autoplay: true
}, _temp);
export { Counter as default };
Counter.propTypes = process.env.NODE_ENV !== "production" ? {
  style: PropTypes.object,
  className: PropTypes.string,

  duration: PropTypes.number,
  from: PropTypes.number,
  to: PropTypes.number,
  suffix: PropTypes.string, // 后缀
  autoplay: PropTypes.bool // 是否自动播放
} : {};

==> seedsui-react-3.6.8.tgz: package/es/Counter/Counter.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { Counter as Instance } from './instance.js';

var Counter = (_temp = _class = function (_Component) {
  _inherits(Counter, _Component);

  function Counter(props) {
    _classCallCheck(this, Counter);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.componentDidMount = function () {
      var instance = new Instance(_this.$el);
      if (_this.props.autoplay) {
        instance.play();
      }
      _this.instance = instance;
    };

    _this.play = function () {
      if (_this.instance) {
        _this.instance.play();
      }
    };

    return _this;
  }

  Counter.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        duration = _props.duration,
        from = _props.from,
        to = _props.to,
        suffix = _props.suffix,
        autoplay = _props.autoplay,
        others = _objectWithoutProperties(_props, ['duration', 'from', 'to', 'suffix', 'autoplay']);

    return React.createElement(
      'span',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, others, { className: 'counter' + (others.className ? ' ' + others.className : ''), 'data-duration': duration, 'data-from': from, 'data-to': to, 'data-suffix': suffix }),
      '1'
    );
  };

  return Counter;
}(Component), _class.defaultProps = {
  duration: 5000,
  from: 0,
  to: 10,
  autoplay: true
}, _temp);
export { Counter as default };
Counter.propTypes = process.env.NODE_ENV !== "production" ? {
  duration: PropTypes.number,
  from: PropTypes.number,
  to: PropTypes.number,
  suffix: PropTypes.string, // 后缀
  autoplay: PropTypes.bool // 是否自动播放
} : {};
